# Configuration

This section includes all configurations available for the stack.

## Configuration File

The stack's configuration file is located at `./easy-cozy/cozystack/cozy.yml`. It can be edited in order to changes various parameters, smtp, logs ...

### SMTP

Modify the `cozy.yml` responsible for the configuration :

```yml title="cozy.yml"
mail:
  # mail noreply address - flags: --mail-noreply-address
  noreply_address: noreply@localhost
  noreply_name: My Cozy
  reply_to: support@cozycloud.cc
  # mail smtp host - flags: --mail-host
  host: smtp.home
  # mail smtp port - flags: --mail-port
  port: 465
  # mail smtp username - flags: --mail-username
  username: { { .Env.COZY_MAIL_USERNAME } }
  # mail smtp password - flags: --mail-password
  password: { { .Env.COZY_MAIL_PASSWORD } }
  # disable mail tls - flags: --mail-disable-tls
  disable_tls: false
  # skip the certificate validation (may be useful on localhost)
  skip_certificate_validation: false
```

:::warning known issue

A known cozy-stack issue [here](https://github.com/cozy/cozy-stack/issues/2009) causes you to have to change the above configuration with:

```yml
mail:
  # mail smtp port - flags: --mail-port
  port: 587
  # disable mail tls - flags: --mail-disable-tls
  disable_tls: true
```

:::

After updating configuration don't forget to restart your cozy-stack :

```bash
docker-compose restart cozy
```

## Stack Version

### Check stack version

```bash
docker-compose exec cozy ./cozy version
```

### Update stack version

Update version in the Dockerfile on gitlab.

**On server :**

1. git pull or change locally the version in cozy-stack/Dockerfile
2. create the docker image using:

   ```bash
   cd /easy-cozy/build
   ./build-docker-image.sh
   ```

3. Start the container based on the built image

   ```bash
   cd ..
   docker-compose up -d cozy
   ```

:::info Error encounter

Docker container was not launched, when consulting logs we can see the following error

> ./cozy: /lib/x86_64-linux-gnu/libc.so.6: version `GLIBC_2.32' not found (required by ./cozy)

We have replaced debian:stable-slim with ubuntu:20.10 as installer for our docker build: https://forge.grandlyon.com/pocs/cozy/easy-cozy/-/commit/48a30a03f209169e0f1ebb0d106bb4361e7cd167

:::
